import Taro from '@tarojs/taro'
import {
  useSelector
} from 'react-redux'
import user from '../reducers/user'

const baseURL = HOST

export default async (options) => {
  const opts = optionBuilder(options)

  return Taro.request(opts[0])
    .then((res) => {
      const {
        data,
        code,
        message
      } = typeof res.data === 'string' ? JSON.parse(res.data) : res.data
      if (code == '1000') {
        return res
      } else if (code === 1005) {
        Taro.showToast({
          title: message,
          icon: 'none'
        })
        throw res
      } else {
        throw res
      }
    })
    .catch((err) => {
      console.log(err, '111111111111');
      if (err.errMsg === "request:fail ") {
        Taro.showToast({
          title: "请检查网络",
          icon: 'none'
        })
        throw err
      }

      throw err
    })
}


export function optionBuilder(options) {
  const {
    url,
    data = {},
    method = 'GET',
    showToast = true,
    autoLogin = true,
    params = {},
    header
  } = options
  //   const showMessage = Object.prototype.hasOwnProperty.call(payload, 'showToast') ? payload.showToast : showToast
  //   const consultant = Taro.getStorageSync('consultantId') || ''
  //   const recommender = Taro.getStorageSync('recommender') || ''
  // const token = useSelector(state => state.user)
  let api = `/api/ma${url}`
  if (method == 'GET' && JSON.stringify(params) != "{}") {
    api = `${api}?${paramsToString(params)}`
  }
  // user.user?.token||
  const token = Taro.getStorageSync('token') || ''
  // console.log(token,'token')
  return [{
      url: `${baseURL}${api}`,
      method,
      data,
      header: {
        'content-type': 'application/json',
        'X-Authorization-JWT': `${token}`,
        // 'appId': appId,
        // 'x-action': 'miniapp',
        // 'x-version': Version,
        // 'x-consultant': consultant,
        // 'x-recommender': recommender,
        ...header || {},
      }
    },
    // {
    // //   showMessage,
    //   // autoLogin
    // }
  ]
}


export const uploadFiles = async (files, url) => {
  const uploads = []
  const token = Taro.getStorageSync('token') || ''
  for (var i = 0; i < files.length; i++) {
    uploads[i] = new Promise((resolve, reject) => {
      Taro.uploadFile({
        url: url || `${baseURL}/api/ma/image`,
        filePath: files[i],
        header: {
          'authorization': `X-Authorization-JWT ${token}`,

          // 'x-action': 'miniapp'
        },
        name: 'file',
        success: function (res) {
          // debugger
          const _data = JSON.parse(res.data)
          // if (_data.code !== CODE_SUCCESS) {
          //   reject(new Error(_data.message))
          // }

          resolve(_data.data)
        },
        fail(err) {
          reject(err)
        }
      })
    })
  }

  return Promise.all(uploads)
}


function paramsToString(params) {
  return Object.keys(params).map((key) => {
    const val = params[key]
    return Array.isArray(val) ? val.map((x) => {
      return composeKeyValue(key, x)
    }).join('&') : composeKeyValue(key, val)

  }).join('&')
}

function composeKeyValue(k, v, encode) {

  return encode === false ? `${k}=${v}` : `${encodeURIComponent(k)}=${encodeURIComponent(v)}`
}
